@@ -183,13 +183,20 @@ async fn execute_command(command: &Value) {
 
 #[tokio::main]
 async fn main() -> Result<(), Error> {
-
     let args: Vec<String> = env::args().collect();
     if args.len() == 1 {
         println!("No command was given.");
         exit(0)
     }
-    let run_command: Vec<&str> = args[1].as_str().split(".").collect();
+    if args.len() == 2 && args[1] == "cmd" {
+        println!("No command was given.");
+        exit(0)
+    }
+    let mut command_index = 1;
+    if args.len() >= 3 && args[1] == "cmd" {
+        command_index = 2;
+    }
+    let run_command: Vec<&str> = args[command_index].as_str().split(".").collect();
     let mut using_cargo: bool = false;
     if fs::metadata("Cargo.toml").is_ok() {
         let cargo_toml_file: String = fs::read_to_string("Cargo.toml").expect("Something went wrong reading the file");
